@@ -1,7 +1,7 @@
 package Time::Duration::Parse::AsHash;
 
-our $DATE = '2016-05-17'; # DATE
-our $VERSION = '0.10.5'; # VERSION
+our $DATE = '2017-01-02'; # DATE
+our $VERSION = '0.10.6'; # VERSION
 
 #IFUNBUILT
 # # use strict;
@@ -74,12 +74,12 @@ sub parse_duration {
     if ($_[0]) {
         return
             ( $res{seconds} || 0) +
-            (($res{minutes} || 0) *      60) +
-            (($res{hours}   || 0) *    3600) +
-            (($res{days}    || 0) *   86400) +
-            (($res{weeks}   || 0) * 7*86400) +
-            (($res{months} || 0) * 30*86400) +
-            (($res{years} || 0) * 365*86400);
+            (($res{minutes} || 0) *        60) +
+            (($res{hours}   || 0) *      3600) +
+            (($res{days}    || 0) *     86400) +
+            (($res{weeks}   || 0) *   7*86400) +
+            (($res{months}  || 0) *  30*86400) +
+            (($res{years}   || 0) * 365*86400);
     }
 
     \%res;
@@ -100,14 +100,16 @@ Time::Duration::Parse::AsHash - Parse string that represents time duration
 
 =head1 VERSION
 
-version 0.10.5
+version 0.10.6
 
 =head1 SYNOPSIS
 
-  use Time::Duration::Parse::AsHash;
+ use Time::Duration::Parse::AsHash;
 
-  my $res = parse_duration("2 minutes and 3 seconds");    # => {minutes=>2, seconds=>3}
-     $res = parse_duration("2 minutes and 3 seconds", 1); # => 123
+ my $res = parse_duration("2 minutes and 3 seconds");    # => {minutes=>2, seconds=>3}
+    $res = parse_duration("2m3.2s", 1); # => 123.2
+
+    $res = parse_duration("01:02:03", 1); # => 3723
 
 =head1 DESCRIPTION
 
@@ -123,22 +125,25 @@ L<DateTime::Duration> and you want to count for leap seconds.
 To return number of seconds like Time::Duration::Parse, pass a true value as the
 second argument.
 
-=item * Seconds are not rounded by default
+=item * By default seconds are not rounded
 
-For example: C<"0.1s"> or C<100ms> will return result C<< { seconds => 0.1 } >>.
+For example: C<"0.1s"> or C<100ms> will return result C<< { seconds => 0.1 } >>,
+and C<"2.3s"> will return C<< { seconds => 2.3 } >>.
 
-Also, in addition to C<01:02:03> being recognized as C<1h2min3s>,
+Also, <01:02:03> being recognized as C<1h2min3s>,
 C<01:02:03.4567> will also be recognized as C<1h2min3.4567s>.
 
-=item * Extra elements recognized
+=item * It recognizes more duration units
 
-C<milliseconds> (or C<ms>). This will be returned in C<seconds> key.
+C<milliseconds> (C<ms>), which will be returned in the C<seconds> key, for
+example C<"400ms"> returns C<< { seconds => 0.4 } >>.
 
 C<microseconds>. This will also be returned in C<seconds> key.
 
-C<nanoseconds> (or C<ns>). This will also be returned in C<seconds> key.
+C<nanoseconds> (C<ns>). This will also be returned in C<seconds> key.
 
-C<decades>. This will be returned in C<years> key.
+C<decades>. This will be returned in C<years> key, for example C<"1.5 decades">
+will return C<< { years => 15 } >>.
 
 =item * It has a lower startup overhead
 
@@ -153,10 +158,17 @@ L<warnings> (starts up in ~3m vs ~9ms on my computer).
 
 Parses duration string and returns hash (unless when the second argument is
 true, in which case will return the number of seconds). Dies on parse failure.
+
+Currently two forms of string are recognized: the first is a series of number
+and time units (e.g. "2 days, 3 hours, 4.5 minutes" or "2h3m4s") and the second
+is time in the format of hh:mm:ss (the seconds can contain decimal numbers) or
+hh:mm.
+
 This function is exported by default.
 
-Note that number of seconds is an approximation: leap seconds are not regarded
-(so a minute is always 60 seconds), a month is 30 days, a year is 365 days.
+Note that if the function is instructed to return number of seconds, the result
+is an approximation: leap seconds are not regarded (so a minute is always 60
+seconds), a month is always 30 days, a year is always 365 days.
 
 =head1 SEE ALSO
 
@@ -168,7 +180,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
